==> aria2_1.4.1.orig.tar.gz: aria2-1.4.1/src/RecoverableException.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_RECOVERABLE_EXCEPTION_H_
#define _D_RECOVERABLE_EXCEPTION_H_
#include "Exception.h"
#include "DownloadResult.h"

namespace aria2 {

class RecoverableException:public Exception {
private:
  DownloadResult::RESULT _code;

protected:
  virtual SharedHandle<Exception> copy() const
  {
    SharedHandle<Exception> e(new RecoverableException(*this));
    return e;
  }
public:
  RecoverableException(const char* file, int line, const std::string& msg):
    Exception(file, line, msg),
    _code(DownloadResult::UNKNOWN_ERROR) {}

  RecoverableException(const char* file, int line, const std::string& msg,
		       const Exception& cause):
    Exception(file, line, msg, cause),
    _code(DownloadResult::UNKNOWN_ERROR) {}

  RecoverableException(const char* file, int line,
		       const RecoverableException& e):
    Exception(file, line, e),
    _code(DownloadResult::UNKNOWN_ERROR) {}
  
  RecoverableException(const char* file, int line, const std::string& msg,
		       DownloadResult::RESULT result):
    Exception(file, line, msg), _code(result) {}

  DownloadResult::RESULT getCode() const { return _code; }
};

} // namespace aria2

#endif // _D_RECOVERABLE_EXCEPTION_EX_H_

==> aria2-1.10.5.tar.gz: aria2-1.10.5/src/RecoverableException.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_RECOVERABLE_EXCEPTION_H_
#define _D_RECOVERABLE_EXCEPTION_H_
#include "Exception.h"
#include "DownloadResultCode.h"

namespace aria2 {

class RecoverableException:public Exception {
private:
  downloadresultcode::RESULT code_;

protected:
  virtual SharedHandle<Exception> copy() const;
public:
  RecoverableException(const char* file, int line, const std::string& msg);

  RecoverableException(const char* file, int line, const std::string& msg,
                       const Exception& cause);

  RecoverableException(const char* file, int line,
                       const RecoverableException& e);

  RecoverableException
  (const char* file, int line, int errnoArg, const std::string& msg);
  
  RecoverableException(const char* file, int line, const std::string& msg,
                       downloadresultcode::RESULT result);

  downloadresultcode::RESULT getCode() const { return code_; }
};

} // namespace aria2

#endif // _D_RECOVERABLE_EXCEPTION_EX_H_
